clear, clc, close all
set(0,'DefaultLineLineWidth',1.5)
format bank
addpath 'C:\Program Files (x86)\REFPROP\'
addpath 'C:\Users\omarv\OneDrive\Documenti\MATLAB\Tesi_magistrale\'

%% WEATHER DATA RETRIEVING
%Oslo weather data 2005
WeatherData=readtable('Osloweather2005.xlsx');
%air temperature
Ta=WeatherData{:,5}'; %K
%incident radiation
It=WeatherData{:,7}'; %W/m^2

%% HEAT DEMAND DEFINITION
%preallocation
D=zeros(1,length(Ta));
for i=1:length(Ta)
    if Ta(i)<15+273.15
        %heat demand when Ta<15°C
        D(i)=50+10.25*(15-Ta(i)+273.15); %kW
    else
        %heat demand when Ta>15°C
        D(i)=50; %kW
    end
end

%% FULL LOAD OPERATION
operation='fl';
%system solution
[COPhp,Qcfl,Qefl,Wcfl,Tcwouthp,Thwouthp]=heatpump_final(operation);
%compressor energy efficiency
etaC=0.85;
%full load power consumption
Wcfl=Wcfl/etaC; %kW

%% PART LOAD OPERATION
operation='pl';
%system solution
[~,Qcpl,Qepl,Wcpl,~,~]=heatpump_final(operation);
%part load power consumption
Wcpl=Wcpl/etaC; %kW

%% PVT PANELS
%PVT panels total area
APVT=4000; %m^2
%PV module surface temperature
TPV=Ta-273.15+20; %°C
%temperature coefficient
beta0=-0.0045; %K^-1
%reference temperature
Tref=25; %°C
%reference electrical efficiency
etaref=0.147;
%optical efficiency
etaO=0.51;
%linear heat loss coefficient
a1=4.93;
%quadratic heat loss coefficient
a2=0.021;
%heat source inlet temperature
Tcwinhp=40+273.15; %K
%average heat source temperature
Thsm=(Tcwinhp+Tcwouthp)/2; %K
%reduced temperature
Tr=(Thsm-Ta)./It;
%preallocation
etael=zeros(1,length(It));
etath=zeros(1,length(It));
for i=1:length(It)
    if It(i)==0
        %electrical efficiency
        etael(i)=0;
        %thermal efficiency
        etath(i)=0;
    else
        %electrical efficiency
        etael(i)=etaref*(1-beta0*(TPV(i)-Tref));
        %thermal efficiency
        etath(i)=etaO-a1*Tr(i)-a2*It(i)*Tr(i)^2;
        if etath(i)<0
            etath(i)=0;
        end
    end
end
%electrical power
Pel=etael.*It*APVT/1000; %kW
%thermal power
Pth=etath.*It*APVT/1000; %kW

%% INTEGRATED ENERGY SYSTEM
%preallocations
operation=zeros(1,length(Ta));
Qc=zeros(1,length(Ta));
Qe=zeros(1,length(Ta));
Wc=ones(1,length(Ta))*Wcfl;
Eimp=zeros(1,length(Ta));
Eexp=zeros(1,length(Ta));
HS=zeros(1,length(Ta));

%maximum battery capacity
Bmax=1000; %kWh
%initial battery storage
B0=0.75*Bmax; %kWh
%battery loading/unloading loss
etaB=0.2;
%preallocation
B=zeros(1,length(Ta));
B(1)=B0;
Bloss=zeros(1,length(Ta));
Bloss(1)=0;

%maximum BTES capacity
Hmax=100*1000; %kWh
%initial BTES storage
H0=0.75*Hmax; %kWh
%BTES loading/unloading loss
etaH=0.1;
%preallocation
H=zeros(1,length(Ta));
H(1)=H0;
Hloss=zeros(1,length(Ta));
Hloss(1)=0;

%maximum PCM capacity
Smax=1000; %kWh
%initial PCM storage
S0=0.75*Smax; %kWh
%PCM loading/unloading loss
etaS=0.1;
%preallocation
S=zeros(1,length(Ta));
S(1)=S0;
Sloss=zeros(1,length(Ta));
Sloss(1)=0;

for i=2:length(Ta)
    if S(i-1)==Smax
        %shut-off operation
        operation(i)=0;
        %shut-off condenser capacity
        Qc(i)=0; %kW
        %shut-off evaporator capacity
        Qe(i)=0; %kW
        %shut-off power consumption
        Wc(i)=0; %kW
        %battery storage after loading
        B(i)=B(i-1)+Pel(i)*1*(1-etaB); %kWh
        %energy loss
        Bloss(i)=Pel(i)*1*etaB; %kWh
        if B(i)>Bmax
            %maximum battery capacity reached
            B(i)=Bmax; %kWh
            %energy loss
            Bloss(i)=(B(i)-B(i-1))*etaB; %kWh
            %power exported to external
            Eexp(i)=Pel(i)-(B(i)-B(i-1))/1*(1+etaB); %kW
        end
        %BTES storage after loading
        H(i)=H(i-1)+(Pth(i)-Qe(i))*1*(1-etaH); %kWh
        if H(i)>Hmax
            %maximum BTES capacity reached
            H(i)=Hmax; %kWh
        end
        %PCM storage after unloading
        S(i)=S(i-1)-D(i)*1*(1+etaS); %kWh
        %heat loss
        Sloss(i)=D(i)*1*etaS; %kWh
        %heat supply
        HS(i)=D(i); %kW
    else
        %full load operation
        operation(i)=2;
        %full load condenser capacity
        Qc(i)=Qcfl; %kW
        %full load evaporator capacity
        Qe(i)=Qefl; %kW
        if Wc(i)<=Pel(i)
            %battery storage after loading
            B(i)=B(i-1)+(Pel(i)-Wc(i))*1*(1-etaB); %kWh
            %energy loss
            Bloss(i)=(Pel(i)-Wc(i))*1*etaB; %kWh
            if B(i)>Bmax
                %maximum battery capacity reached
                B(i)=Bmax; %kWh
                %energy loss
                Bloss(i)=(B(i)-B(i-1))*etaB; %kWh
                %power exported to external
                Eexp(i)=(Pel(i)-Wc(i))-(B(i)-B(i-1))/1*(1+etaB); %kW
            end
        elseif Wc(i)<=Pel(i)+B(i-1)/1
            %battery storage after unloading
            B(i)=B(i-1)-(Wc(i)-Pel(i))*1*(1+etaB); %kWh
            %energy loss
            Bloss(i)=(Wc(i)-Pel(i))*1*etaB; %kWh
            if (Wc(i)-Pel(i))*1*(1+etaB)>B(i-1)
                %minimum battery capacity reached
                B(i)=0; %kWh
                %energy loss
                Bloss(i)=(B(i-1)-B(i))*etaB; %kWh
            end
        else
            %part load operation
            operation(i)=1;
            %part load condenser capacity
            Qc(i)=Qcpl; %kW
            %part load evaporator capacity
            Qe(i)=Qepl; %kW
            %part load power consumption
            Wc(i)=Wcpl; %kW
            if Wc(i)<=Pel(i)
                %battery storage after loading
                B(i)=B(i-1)+(Pel(i)-Wc(i))*1*(1-etaB); %kWh
                %energy loss
                Bloss(i)=(Pel(i)-Wc(i))*1*etaB; %kWh
                if B(i)>Bmax
                    %maximum battery capacity reached
                    B(i)=Bmax; %kWh
                    %energy loss
                    Bloss(i)=(B(i)-B(i-1))*etaB; %kWh
                    %power exported to external
                    Eexp(i)=(Pel(i)-Wc(i))-(B(i)-B(i-1))/1*(1+etaB); %kW
                end
            elseif Wc(i)<=Pel(i)+B(i-1)/1
                %battery storage after unloading
                B(i)=B(i-1)-(Wc(i)-Pel(i))*1*(1+etaB); %kWh
                %energy loss
                Bloss(i)=(Wc(i)-Pel(i))*1*etaB; %kWh
                if (Wc(i)-Pel(i))*1*(1+etaB)>B(i-1)
                    %minimum battery capacity reached
                    B(i)=0; %kWh
                    %energy loss
                    Bloss(i)=(B(i-1)-B(i))*etaB; %kWh
                end
            else
                operation(i)=3;
                %power imported from external
                Eimp(i)=100; %kW
                %full load condenser capacity
                Qc(i)=Qcfl; %kW
                %full load evaporator capacity
                Qe(i)=Qefl; %kW
                %full load power consumption
                Wc(i)=Wcfl; %kW
                %battery storage after loading
                B(i)=B(i-1)+(Eimp(i)+Pel(i)-Wc(i))*1*(1-etaB); %kWh
                %energy loss
                Bloss(i)=(Eimp(i)+Pel(i)-Wc(i))*1*etaB; %kWh
                if B(i)>Bmax
                    %maximum battery capacity reached
                    B(i)=Bmax; %kWh
                    %energy loss
                    Bloss(i)=(B(i)-B(i-1))*etaB; %kWh
                    %power exported to external
                    Eexp(i)=(Pel(i)-Wc(i))-(B(i)-B(i-1))/1*(1+etaB); %kW
                end
            end
        end
        if Qe(i)<=Pth(i)
            %BTES storage after loading
            H(i)=H(i-1)+(Pth(i)-Qe(i))*1*(1-etaH); %kWh
            %heat loss
            Hloss(i)=(Pth(i)-Qe(i))*1*etaH; %kWh
            if H(i)>Hmax
                %maximum BTES capacity reached
                H(i)=Hmax; %kWh
                %heat loss
                Hloss(i)=(H(i)-H(i-1))*etaH; %kWh
            end
        else
            %BTES storage after unloading
            H(i)=H(i-1)-(Qe(i)-Pth(i))*1*(1+etaH); %kWh
            %heat loss
            Hloss(i)=(Qe(i)-Pth(i))*1*etaH; %kWh
            if H(i)<0.01*Hmax
                %minimum BTES capacity reached
                H(i)=0.01*Hmax; %kWh
                %heat loss
                Hloss(i)=(H(i-1)-H(i))*etaH; %kWh
            end
        end
        if D(i)<=Qc(i)
            %heat supply
            HS(i)=D(i); %kW            
            %PCM storage after loading
            S(i)=S(i-1)+(Qc(i)-D(i))*1*(1-etaS); %kWh
            %heat loss
            Sloss(i)=(Qc(i)-D(i))*etaS; %kWh
            if S(i)>Smax
                %maximum PCM capacity reached
                S(i)=Smax; %kWh
                %heat loss
                Sloss(i)=(S(i)-S(i-1))*etaS; %kWh
            end
        else
            %PCM storage after unloading
            S(i)=S(i-1)-(D(i)-Qc(i))*1*(1+etaS); %kWh
            %heat loss
            Sloss(i)=(D(i)-Qc(i))*1*etaS; %kWh
            if (D(i)-Qc(i))*1*(1+etaS)>S(i-1)
                %minimum PCM capacity reached
                S(i)=0; %kWh
                %heat loss
                Sloss(i)=(S(i-1)-S(i))*etaS; %kWh
                %heat supply
                HS(i)=Qc(i)+S(i-1)/1*(1-etaS); %kW
            else
                %heat supply
                HS(i)=D(i); %kW
            end
        end
    end
end
clc
%power balance
PB=Qc-D; %kW
%heat available
HA=Qc+S/1; %kW
%demand minus availability
DA=D-HA; %kW
%demand minus supply
DS=D-HS; %kW

%% YEARLY RESULTS
MonthlyDays=[31,28,31,30,31,30,31,31,30,31,30,31];
MonthlyHours=MonthlyDays*24;

figure(1)
hold on
Taa=zeros(1,53);
for w=1:52
    Taa(w)=mean(Ta((w-1)*7*24+1:w*7*24))-273.15;
end
Taa(end)=mean(Ta(w*7*24:end))-273.15;
plot(1:1:(w+1),Taa,'b-')
clear('Taa')
xlabel('Weeks')
ylabel('[°C]')
legend('Oslo 2005')
title('Average Air Temperature')
grid on
xlim([1,w+1])
winavgTa=mean([Ta(1:sum(MonthlyHours(1:2))+20*24),Ta(sum(MonthlyHours(1:11))+20*24+1:end)])-273.15;
sumavgTa=mean(Ta(sum(MonthlyHours(1:5))+20*24+1:sum(MonthlyHours(1:8))+22*24))-273.15;

figure(2)
hold on
Ita=zeros(1,53);
for w=1:52
    Ita(w)=mean(It((w-1)*7*24+1:w*7*24));
end
Ita(end)=mean(It(w*7*24:end));
plot(1:1:(w+1),Ita,'r-')
clear('Ita')
xlabel('Weeks')
ylabel('[W/m^2]')
legend('Oslo 2005')
title('Average Incident Radiation')
grid on
xlim([1,w+1])
winavgIt=mean([It(1:sum(MonthlyHours(1:2))+20*24),It(sum(MonthlyHours(1:11))+20*24+1:end)]);
sumavgIt=mean(It(sum(MonthlyHours(1:5))+20*24+1:sum(MonthlyHours(1:8))+22*24));

sz=[5,3];
varTypes=["string","double","double"];
varNames=["Period";"Air Temperature [°C]";"Solar Irradiance [kW/m^2]"];
Averages=table('Size',sz,'VariableTypes',varTypes,'VariableNames',varNames);
Average=["Maximum";"Minimum";"Winter Average";"Summer Average";"Yearly Average"];
Averages{:,1}=Average;
Averages{1,2:3}=[max(Ta)-273.15,max(It)];
Averages{2,2:3}=[min(Ta)-273.15,min(It)];
Averages{3,2:3}=[winavgTa,winavgIt];
Averages{4,2:3}=[sumavgTa,sumavgIt];
Averages{5,2:3}=[mean(Ta-273.15),mean(It)];
disp(Averages)
clear('varTypes','varNames','Average','winavgTa','winavgIt','sumavgTa','sumavgIt')

figure(3)
hold on
plot(operation,'k.','LineWidth',0.5)
xlabel('Hours')
title('Heat Pump Operational Modes')
grid on
xlim([0,length(Ta)])
ylim([-0.5,3.5])
yticks([0,1,2,3])
yticklabels({'Shut-off','Part Load','Full Load Internal','Full Load External'})

sz=[5,5];
varTypes=["string","double","double","double","double"];
varNames=["Period";"Hours Full Load";"Hours Part Load";"Hours Shut-off";"Hours Externally Driven"];
Results1=table('Size',sz,'VariableTypes',varTypes,'VariableNames',varNames);
%considered periods
Period=["January";"April";"July";"October";"Year"];
%Hours of full load operation
HoursFullLoad=[nnz(operation(2:sum(MonthlyHours(1:1)))==(2))+1
               nnz(operation(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))==2)
               nnz(operation(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))==2)
               nnz(operation(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))==2)
               nnz(operation==2)];
%hours of part load operation
HoursPartLoad=[nnz(operation(2:sum(MonthlyHours(1:1)))==1)
               nnz(operation(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))==1)
               nnz(operation(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))==1)
               nnz(operation(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))==1)
               nnz(operation==1)];
%hours of shut-off operation
HoursShutoff=[nnz(operation(2:sum(MonthlyHours(1:1)))==0)
              nnz(operation(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))==0)
              nnz(operation(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))==0)
              nnz(operation(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))==0)
              nnz(operation==0)];
%hours of externally driven operation
HoursExtDriv=[nnz(operation(2:sum(MonthlyHours(1:1)))==(3))+1
              nnz(operation(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))==3)
              nnz(operation(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))==3)
              nnz(operation(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))==3)
              nnz(operation==3)];
Results1{:,1}=Period;
Results1{:,2}=HoursFullLoad;
Results1{:,3}=HoursPartLoad;
Results1{:,4}=HoursShutoff;
Results1{:,5}=HoursExtDriv;
disp(Results1)
clear('HoursFullLoad','HoursPartLoad','HoursShutoff','HoursExtDriv')

figure(4)
hold on
plot(Qc,'r-','LineWidth',0.5)
plot(D,'b-','LineWidth',0.5)
xlabel('Hours')
ylabel('[kW]')
legend('Heat Pump Capacity','Heat Demand')
title('Capacity vs. Demand')
grid on
xlim([1,length(Ta)])
ylim([0,350])

figure(5)
hold on
QCa=zeros(1,52);
for w=1:52
    QCa(w)=sum(Qc((w-1)*7*24+1:w*7*24)*1);
end
plot(1:1:52,QCa/1000,'r-')
clear('QCa')
xlabel('Weeks')
ylabel('[MWh]')
title('Total Heat Pump Capacity per Week')
grid on
xlim([1,52])
ylim([0,40])

figure(6)
hold on
Da=zeros(1,52);
HAa=zeros(1,52);
for w=1:52
    Da(w)=mean(D((w-1)*7*24+1:w*7*24));
    HAa(w)=mean(HA((w-1)*7*24+1:w*7*24));
end
plot(1:1:52,Da,'b-')
plot(1:1:52,HAa,'g-')
clear('Da','HAa')
xlabel('Weeks')
ylabel('[kW]')
legend('Average Heat Demand','Average Heat Available')
title('Heat Available vs. Heat Demand')
grid on
xlim([1,52])
ylim([0,1200])

sz=[5,3];
varTypes=["string","double","double"];
varNames=["Period";"Hours Insuf Heat";"Total Ins Heat [MWh]"];
Results2=table('Size',sz,'VariableTypes',varTypes,'VariableNames',varNames);
%hours with insufficient heat production
HoursInsHeat=[nnz(DA(2:sum(MonthlyHours(1:1)))>0)
              nnz(DA(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))>0)
              nnz(DA(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))>0)
              nnz(DA(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))>0)
              nnz(DA>0)];
%total insufficient heat
TotalInsHeat=[-sum(-DA(2:sum(MonthlyHours(1:1))).*(DA(2:sum(MonthlyHours(1:1)))>0))*1
              -sum(-DA(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4))).*(DA(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))>0))*1
              -sum(-DA(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7))).*(DA(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))>0))*1
              -sum(-DA(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10))).*(DA(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))>0))*1
              -sum(-DA.*(DA>0))*1]/1000;
Results2{:,1}=Period;
Results2{:,2}=HoursInsHeat;
Results2{:,3}=TotalInsHeat;
disp(Results2)
clear('varTypes','varNames','HoursFullLoad','HoursInsHeat','TotalInsHeat')

sz=[5,7];
varTypes=["string","double","double","double","double","double","double"];
varNames=["Period";"Total Solar Energy Produced [MWh]";"Total Energy Consumed [MWh]";"Total Heat Produced [MWh]";"Total Heat Supplied [MWh]";"Total Energy Imported [MWh]";"Total Energy Exported"];
Results3=table('Size',sz,'VariableTypes',varTypes,'VariableNames',varNames);
%total energy produced by PVT panels
TotalEnerProd=[sum(Pel(2:sum(MonthlyHours(1:1)))*1)
              sum(Pel(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
              sum(Pel(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
              sum(Pel(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
              sum(Pel*1)]/1000;
%total energy consumed by the heat pump
TotalEnerCons=[sum(Wc(2:sum(MonthlyHours(1:1)))*1)
               sum(Wc(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
               sum(Wc(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
               sum(Wc(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
               sum(Wc*1)]/1000;
%total heat produced by the heat pump
TotalHeatProd=[sum(Qc(2:sum(MonthlyHours(1:1)))*1)
               sum(Qc(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
               sum(Qc(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
               sum(Qc(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
               sum(Qc*1)]/1000;
%total heat supplied to district heating
TotalHeatSupp=[sum(HS(2:sum(MonthlyHours(1:1)))*1)
               sum(HS(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
               sum(HS(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
               sum(HS(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
               sum(HS*1)]/1000;
%total energy imported
TotalImpEner=[sum(Eimp(2:sum(MonthlyHours(1:1)))*1)
              sum(Eimp(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
              sum(Eimp(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
              sum(Eimp(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
              sum(Eimp*1)]/1000;
%total energy exported
TotalExpEner=[sum(Eexp(2:sum(MonthlyHours(1:1)))*1)
              sum(Eexp(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
              sum(Eexp(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
              sum(Eexp(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
              sum(Eexp*1)]/1000;
Results3{:,1}=Period;
Results3{:,2}=TotalEnerProd;
Results3{:,3}=TotalEnerCons;
Results3{:,4}=TotalHeatProd;
Results3{:,5}=TotalHeatSupp;
Results3{:,6}=TotalImpEner;
Results3{:,7}=TotalExpEner;
disp(Results3)
clear('varTypes','varNames','TotalEnerProd','TotalEnerCons','TotalHeatProd','TotalHeatSupp','TotalImpEner','TotalExpEner')

sz=[5,4];
varTypes=["string","double","double","double"];
varNames=["Period";"Total Energy Loss by Battery [MWh]";"Total Energy Loss by BTES [MWh]";"Total Energy Loss by PCM-TES [MWh]"];
Results4=table('Size',sz,'VariableTypes',varTypes,'VariableNames',varNames);
%total energy lost by battery
LossBattery=[sum(Bloss(2:sum(MonthlyHours(1:1)))*1)
             sum(Bloss(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
             sum(Bloss(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
             sum(Bloss(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
             sum(Bloss*1)]/1000;
%total energy lost by BTES
LossBTES=[sum(Hloss(2:sum(MonthlyHours(1:1)))*1)
          sum(Hloss(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
          sum(Hloss(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
          sum(Hloss(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
          sum(Hloss*1)]/1000;
%total energy lost by PCM-TES
LossPCM=[sum(Sloss(2:sum(MonthlyHours(1:1)))*1)
         sum(Sloss(1+sum(MonthlyHours(1:3)):sum(MonthlyHours(1:4)))*1)
         sum(Sloss(1+sum(MonthlyHours(1:6)):sum(MonthlyHours(1:7)))*1)
         sum(Sloss(1+sum(MonthlyHours(1:9)):sum(MonthlyHours(1:10)))*1)
         sum(Sloss*1)]/1000;
Results4{:,1}=Period;
Results4{:,2}=LossBattery;
Results4{:,3}=LossBTES;
Results4{:,4}=LossPCM;
disp(Results4)
clear('varTypes','varNames','LossBattery','LossBTES','LossPCM')

%% WINTER RESULTS
set(0,'DefaultLineLineWidth',1)
figure(7)
hold on
plot(1:1:sum(MonthlyHours(1:1)),Wc(1:sum(MonthlyHours(1:1))),'b-')
plot(1:1:sum(MonthlyHours(1:1)),B(1:sum(MonthlyHours(1:1)))/1,'-','Color',[0.65,0.65,0.65])
plot(1:1:sum(MonthlyHours(1:1)),Pel(1:sum(MonthlyHours(1:1))),'r-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Electrical Consumption','Battery Capacity','PVT Electrical Production')
title('January')
grid on
xlim([1,sum(MonthlyHours(1:1))])
ylim([0,300])

figure(8)
hold on
yyaxis left
plot(1:1:sum(MonthlyHours(1:1)),Qe(1:sum(MonthlyHours(1:1))),'b-')
plot(1:1:sum(MonthlyHours(1:1)),Pth(1:sum(MonthlyHours(1:1))),'r-','LineWidth',1.5)
xlabel('Hours')
ylabel('[kW]')
xlim([1,sum(MonthlyHours(1:1))])
ylim([0,300])
set(gca,'YColor','k')
yyaxis right
plot(1:1:sum(MonthlyHours(1:1)),H(1:sum(MonthlyHours(1:1)))*1,'-','Color',[0.65,0.65,0.65])
ylabel('[kW]')
set(gca,'Yscale','log')
ylim([1,2e5])
set(gca,'YColor','k')
yyaxis left
legend('HP Thermal Consumption (left)','PVT Thermal Production (left)','BTES Capacity (right)')
title('January')
grid on

figure(9)
hold on
plot(1:1:sum(MonthlyHours(1:1)),Qc(1:sum(MonthlyHours(1:1))),'r-')
plot(1:1:sum(MonthlyHours(1:1)),S(1:sum(MonthlyHours(1:1)))*1,'-','Color',[0.65,0.65,0.65])
plot(1:1:sum(MonthlyHours(1:1)),D(1:sum(MonthlyHours(1:1))),'b-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Thermal Production','PCM-TES Capacity','DH Thermal Consumption')
title('January')
grid on
xlim([1,sum(MonthlyHours(1:1))])

%% SUMMER RESULTS
set(0,'DefaultLineLineWidth',1)
figure(10)
hold on
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),Wc(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'b-')
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),B(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7)))/1,'-','Color',[0.65,0.65,0.65])
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),Pel(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'r-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Electrical Consumption','Battery Capacity','PVT Electrical Production')
title('July')
grid on
xlim([sum(MonthlyHours(1:6))+1,sum(MonthlyHours(1:7))])

figure(11)
hold on
yyaxis left
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),Qe(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'b-')
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),Pth(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'r-')
xlabel('Hours')
ylabel('[kW]')
xlim([sum(MonthlyHours(1:6))+1,sum(MonthlyHours(1:7))])
ylim([0,1600])
set(gca,'YColor','k')
yyaxis right
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),H(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7)))*1,'-','Color',[0.65,0.65,0.65])
ylabel('[kW]')
ylim([0,1.1e5])
set(gca,'YColor','k')
yyaxis left
legend('HP Thermal Consumption (left)','PVT Thermal Production (left)','BTES Capacity (right)')
title('July')
grid on

figure(12)
hold on
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),Qc(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'r-')
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),S(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7)))*1,'-','Color',[0.65,0.65,0.65])
plot(sum(MonthlyHours(1:6))+1:1:sum(MonthlyHours(1:7)),D(sum(MonthlyHours(1:6))+1:sum(MonthlyHours(1:7))),'b-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Thermal Production','PCM-TES Capacity','DH Thermal Consumption')
title('July')
grid on
xlim([sum(MonthlyHours(1:6))+1,sum(MonthlyHours(1:7))])

%% SPRING/FALL RESULTS
set(0,'DefaultLineLineWidth',1)
figure(13)
hold on
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),Wc(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'b-')
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),B(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4)))/1,'-','Color',[0.65,0.65,0.65])
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),Pel(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'r-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Electrical Consumption','Battery Capacity','PVT Electrical Production')
title('April')
grid on
xlim([sum(MonthlyHours(1:3))+1,sum(MonthlyHours(1:4))])

figure(14)
hold on
yyaxis left
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),Qe(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'b-')
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),Pth(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'r-')
xlabel('Hours')
ylabel('[kW]')
xlim([sum(MonthlyHours(1:3))+1,sum(MonthlyHours(1:4))])
ylim([0,1600])
set(gca,'YColor','k')
yyaxis right
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),H(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4)))*1,'-','Color',[0.65,0.65,0.65])
ylabel('[kW]')
ylim([0,5e3])
set(gca,'YColor','k')
yyaxis left
legend('HP Thermal Consumption (left)','PVT Thermal Production (left)','BTES Capacity (right)')
title('April')
grid on

figure(15)
hold on
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),Qc(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'r-')
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),S(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4)))*1,'-','Color',[0.65,0.65,0.65])
plot(sum(MonthlyHours(1:3))+1:1:sum(MonthlyHours(1:4)),D(sum(MonthlyHours(1:3))+1:sum(MonthlyHours(1:4))),'b-')
xlabel('Hours')
ylabel('[kW]')
legend('HP Thermal Production','PCM-TES Capacity','DH Thermal Consumption')
title('April')
grid on
xlim([sum(MonthlyHours(1:3))+1,sum(MonthlyHours(1:4))])